/**
 * @file
 * @author  Caleb Fangmeier <caleb@fangmeier.tech>
 * @version 0.1
 *
 * @section LICENSE
 *
 *
 * MIT License
 *
 * Copyright (c) 2017 Caleb Fangmeier
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 * @section DESCRIPTION
 */
#ifndef datafile_hpp
#define datafile_hpp

#include <vector>
#include <string>
#include <fstream>
#include <iostream>

namespace fv::util{

struct DataFileDescriptor{
    std::string filename;
    std::string label;
    std::string category; //TODO: Populate this

    DataFileDescriptor(const std::string filename, const std::string label)
      :filename(filename), label(label),category("") { }

    DataFileDescriptor(const std::string line):category(""){
        std::string::size_type col_pos = line.find(":");
        if(col_pos == std::string::npos){
            this->filename = line;
            this->label = "";
        } else{
            this->filename = line.substr(0, col_pos);
            this->label = line.substr(col_pos+1);
        }
    }

};

// input list should be a file containing line-delineated filename for all Data
// Files with an optional label separated by a comma.
std::vector<DataFileDescriptor> read_input_list(const std::string &filename){
    std::ifstream istrm(filename, std::ios::in);

    std::string line;
    std::vector<DataFileDescriptor> dfds;
    std::string prefix = filename.substr(0, filename.find_last_of("/")+1);
    while(std::getline(istrm, line)){
        if(line[0] != '#')
        dfds.push_back(DataFileDescriptor(prefix+line));
    }
    return dfds;
}
}
#endif // datafile_hpp
